<?php  namespace Concrete\Package\EzProduct\Block\EzProduct;
use Concrete\Core\Block\BlockController;
use Concrete\Core\Support\Facade\Application;
use Concrete\Core\File\File;
use Concrete\Core\Page\Page;

defined('C5_EXECUTE') or die("Access Denied."); 
class Controller extends BlockController
{
    protected $btTable = 'btEzproduct';
    protected $btInterfaceWidth = "580";
    protected $btWrapperClass = 'ccm-ui';
    protected $btInterfaceHeight = "460";
	protected $btDefaultSet = 'ezproduct';

    public function getBlockTypeDescription() {
        return t("Add a product to any page.");
    }

    public function getBlockTypeName() {
        return t("EZ Product");
    }
	
	public function on_start() {
		if(!is_object($this->app)){
			$this->app = \Concrete\Core\Support\Facade\Application::getFacadeApplication();
			$this->set('app', $this->app);
		}
	}
	public function add() {
        $this->edit();
    }
	public function edit() {
		$this->set('app', Application::getFacadeApplication());
	}
	public function getFileID() {
        return $this->fID;
    }
	public function getFileObject() {
        return File::getByID($this->fID);
    }
	function getExternalLink() {return $this->externalLink;}
	function getInternalLinkCID() {return $this->internalLinkCID;}
	function getLinkURL() {
		if (!empty($this->externalLink)) {
			return $this->externalLink;
		} else if (!empty($this->internalLinkCID)) {
			$linkToC = Page::getByID($this->internalLinkCID);
			return (empty($linkToC) || $linkToC->error) ? '' : $this->app->make('helper/navigation')->getLinkToCollection($linkToC);
		} else {
			return '';
		}
	}
	function getExternalLink2() {return $this->externalLink2;}
	function getInternalLink2CID() {return $this->internalLink2CID;}
	function getLinkURL2() {
		if (!empty($this->externalLink2)) {
			return $this->externalLink2;
		} else if (!empty($this->internalLink2CID)) {
			$linkToC = Page::getByID($this->internalLink2CID);
			return (empty($linkToC) || $linkToC->error) ? '' : $this->app->make('helper/navigation')->getLinkToCollection($linkToC);
		} else {
			return '';
		}
	}
	
	public function validate($args) {
        if (!is_object($this->app)) {
            $app = Application::getFacadeApplication();
        } else {
            $app = $this->app;
        }
		$e = $app->make('error');      
		if(empty($args['productName'])){
            $e->add(t("Product Name required."));
        }
		if(strlen($args['productName']) > 127) {
			$e->add(t("Product Name cannot exceed 127 characters."));
		}
		if(empty($args['productNum'])){
            $e->add(t("Product Number required."));
        }
		if(strlen($args['productNum']) > 127) {
			$e->add(t("Product Number cannot exceed 127 characters."));
		}
		if(empty($args['business'])){
            $e->add(t("Paypal Email required."));
        }
		if(empty($args['fID'])){
            $e->add(t("Product Image is required."));
        } elseif (!empty($args['fID'])) {
			$f = File::getByID($args['fID']); // Get the file	
			$fv = $f->getVersion();  // Get the file version
			$fileType = $fv->getExtension();  // Get the file extension
			$ftypes = array("jpg", "JPG", "jpeg", "png", "PNG"); // Define array of file types.
			if(!in_array($fileType, $ftypes)) {   // If the file extension is NOT in the array, return this error.
				$e->add(t("Invalid product image type. Please select either a PNG or JPG file."));
			}
		}
		return $e;
	}
	public function save($data) { 
		if (!is_object($this->app)) {
            $app = Application::getFacadeApplication();
        } else {
            $app = $this->app;
        }
		$data['cmdType'] = isset($data['cmdType']) ? trim($data['cmdType']) : 'xclick';
		$data['enableOptsets'] = isset($data['enableOptsets']) ? trim($data['enableOptsets']) : 'no';
		$data['enablePoptions'] = isset($data['enablePoptions']) ? trim($data['enablePoptions']) : 'no';
		$data['disableProd'] = isset($data['disableProd']) ? trim($data['disableProd']) : 'never';
		$data['saleSet'] = isset($data['saleSet']) ? trim($data['saleSet']) : 'always';
		$data['cCode'] = isset($data['cCode']) ? trim($data['cCode']) : 'USD';
		$data['curs'] = isset($data['curs']) ? trim($data['curs']) : '$';
		$data['cTarg'] = isset($data['cTarg']) ? trim($data['cTarg']) : 'self';
		$data['btnStyle'] = isset($data['btnStyle']) ? trim($data['btnStyle']) : 'default';
		$data['itemQty'] = is_numeric($data['itemQty']) ? intval($data['itemQty']) : '1';
		$data['taxType'] = isset($data['taxType']) ? trim($data['taxType']) : 'none';
		$data['discountType'] = isset($data['discountType']) ? trim($data['discountType']) : 'none';
		$data['unqty'] = ($data['unqty']) ? '1' : '0';
		$data['noShipping'] = isset($data['noShipping']) ? trim($data['noShipping']) : '0';
		
		$data['disableDate'] = $app->make('helper/form/date_time')->translate('disableDate');
		$data['saleEnddate'] = $app->make('helper/form/date_time')->translate('saleEnddate');
		$data['saleStartdate'] = $app->make('helper/form/date_time')->translate('saleStartdate');
		$data['saleStart'] = $app->make('helper/form/date_time')->translate('saleStart');
		$data['saleEnd'] = $app->make('helper/form/date_time')->translate('saleEnd');
		
		switch (intval($data['linkType'])) {
			case 1:
				$data['externalLink'] = '';
				break;
			case 2:
				$data['internalLinkCID'] = 0;
				break;
			default:
				$data['externalLink'] = '';
				$data['internalLinkCID'] = 0;
				break;
		}
		unset($data['linkType']);
		switch (intval($data['linkType2'])) {
			case 1:
				$data['externalLink2'] = '';
				break;
			case 2:
				$data['internalLink2CID'] = 0;
				break;
			default:
				$data['externalLink2'] = '';
				$data['internalLink2CID'] = 0;
				break;
		}
		unset($data['linkType2']);
		parent::save($data);
	}
}